@@ -61,7 +61,23 @@
 #'
 #' @return Objects inheriting from `bicop_dist` for `bicop_dist()`, and
 #' `bicop` and `bicop_dist` for `bicop()`.
-#'
+#' 
+#' Object from the `bicop_dist` class are lists containing:
+#' 
+#' * `family`, a `character` indicating the copula family.
+#' * `rotation`, an `integer` indicating the rotation (i.e., either 0, 90, 180, 
+#' or 270).
+#' * `parameters`, a `numeric` vector or matrix of parameters.
+#' * `npars`, a `numeric` with the (effective) number of parameters.
+#' 
+#' Additionally, objects from the `bicop` class contain:
+#' 
+#' * `data` (optionally, if `keep_data = TRUE` was used), the dataset that was 
+#' passed to [bicop()].
+#' * `controls`, a `list` with the set of fit controls that was passed to [bicop()].
+#' * `nobs`, an `integer` with the number of observations that was used 
+#' to fit the model.
+#' 
 #' @examples
 #' ## bicop_dist objects
 #' bicop_dist("gaussian", 0, 0.5)
@@ -77,6 +93,18 @@
 bicop <- function(data, family_set = "all", par_method = "mle",
                   nonpar_method = "quadratic", mult = 1, selcrit = "bic", 
                   psi0 = 0.9, presel = TRUE, keep_data = TRUE, cores = 1) {
+    assert_that(
+        is.character(family_set), 
+        is.string(par_method), 
+        is.string(nonpar_method),
+        is.number(mult), mult > 0,
+        is.string(selcrit),
+        is.number(psi0), psi0 > 0, psi0 < 1,
+        is.flag(presel),
+        is.flag(keep_data),
+        is.number(cores), cores > 0
+    )
+    
     stopifnot(ncol(data) == 2)
     # check if families known (w/ partial matching) and expand convenience defs
     family_set <- process_family_set(family_set)
@@ -127,9 +155,10 @@ as.bicop <- function(object) {
 #' @rdname bicop
 #' @export
 bicop_dist <- function(family = "indep", rotation = 0, parameters = numeric(0)) {
-    stopifnot(length(family) == 1)
+    assert_that(is.string(family), is.number(rotation), is.numeric(parameters))
     if (family %in% setdiff(family_set_nonparametric, "indep"))
         stop("bicop_dist should not be used directly with nonparametric families.")
+    
     family <- family_set_all[pmatch(family, family_set_all)]
     dist <- list(family     = family,
                  rotation   = rotation,
