@@ -41,6 +41,25 @@
 #'
 #' @return Objects inheriting from `vinecop_dist` for [vinecop_dist()], and
 #' `vinecop` and `vinecop_dist` for [vinecop()].
+#' 
+#' Object from the `vinecop_dist` class are lists containing:
+#' 
+#' * `pair_copulas`, a list of lists. Each element of `pair_copulas` corresponds 
+#' to a tree, which is itself a list of `bicop_dist` objects, see [bicop_dist()].
+#' * `matrix`, an R-vine matrix, namely a compressed representation of the 
+#' vine structure, see [check_rvine_matrix()].
+#' * `npars`, a `numeric` with the number of (effective) parameters.
+#' 
+#' For objects from the `vinecop` class, elements of the sublists in 
+#' `pair_copulas` are also `bicop` objects, see [bicop()]. Additionally, 
+#' objects from the `vinecop` class contain:
+#' 
+#' * `threshold`, the (set or estimated) threshold used for thresholding the vine.
+#' * `data` (optionally, if `keep_data = TRUE` was used), the dataset that was 
+#' passed to [vinecop()].
+#' * `controls`, a `list` with the set of fit controls that was passed to [vinecop()].
+#' * `nobs`, an `integer` with the number of observations that was used 
+#' to fit the model.
 #'
 #' @examples
 #' # specify pair-copulas
@@ -74,6 +93,21 @@ vinecop <- function(data, family_set = "all", matrix = NA,
                     mult = 1, selcrit = "bic", psi0 = 0.9, presel = TRUE, 
                     trunc_lvl = Inf, tree_crit = "tau", threshold = 0, 
                     keep_data = TRUE, show_trace = FALSE, cores = 1) {
+    assert_that(
+        is.character(family_set), 
+        is.string(par_method), 
+        is.string(nonpar_method),
+        is.number(mult), mult > 0,
+        is.string(selcrit),
+        is.number(psi0), psi0 > 0, psi0 < 1,
+        is.flag(presel),
+        is.scalar(trunc_lvl),
+        is.string(tree_crit),
+        is.scalar(threshold),
+        is.flag(keep_data),
+        is.number(cores), cores > 0
+    )
+    
     # check if families known (w/ partial matching) and expand convenience defs
     family_set <- process_family_set(family_set)
     
@@ -146,7 +180,7 @@ vinecop_dist <- function(pair_copulas, matrix) {
     )
     
     # sanity checks
-    stopifnot(is.list(pair_copulas))
+    assert_that(is.list(pair_copulas))
     pc_lst <- unlist(pair_copulas, recursive = FALSE)
     if (!all(sapply(pc_lst, function(x) inherits(x, "bicop_dist")))) {
         stop("some objects in pair_copulas aren't of class 'bicop_dist'")
@@ -154,6 +188,7 @@ vinecop_dist <- function(pair_copulas, matrix) {
     vinecop_check_cpp(vinecop)
     check_rvine_matrix(matrix)
     vinecop$npars <- sum(sapply(pc_lst, function(x) x[["npars"]]))
+    vinecop$loglik <- NA
     
     vinecop
 }
