@@ -57,10 +57,23 @@
 #' # evaluate the density and cdf
 #' dvinecop(u[1, ], vc)
 #' pvinecop(u[1, ], vc)
+#' 
+#' # get single pair copula
+#' get_pair_copula(vc, 1, 1)
+#' 
+#' # get all pair copulas
+#' get_all_pair_copulas(vc)
+#' 
+#' # get vine matrix
+#' get_matrix(vc)
+#' 
+#' # extract a truncated sub-vine based on truncation level supplied by user
+#' truncate_model(vc, 1)
+#' 
 #' @rdname vinecop_methods
 #' @export
 dvinecop <- function(u, vinecop) {
-    stopifnot(inherits(vinecop, "vinecop_dist"))
+    assert_that(inherits(vinecop, "vinecop_dist"))
     vinecop_pdf_cpp(if_vec_to_matrix(u), vinecop)
 }
 
@@ -68,7 +81,7 @@ dvinecop <- function(u, vinecop) {
 #' @param n_mc number of samples used for quasi Monte Carlo integration.
 #' @export
 pvinecop <- function(u, vinecop, n_mc = 10^4) {
-    stopifnot(inherits(vinecop, "vinecop_dist"))
+    assert_that(inherits(vinecop, "vinecop_dist"), is.number(n_mc))
     vinecop_cdf_cpp(if_vec_to_matrix(u), vinecop, n_mc)
 }
 
@@ -80,10 +93,9 @@ pvinecop <- function(u, vinecop, n_mc = 10^4) {
 #'    from `vinecop`.
 #' @export
 rvinecop <- function(n, vinecop, U = NULL) {
-    stopifnot(inherits(vinecop, "vinecop_dist"))
+    assert_that(inherits(vinecop, "vinecop_dist"))
     d <- ncol(vinecop$matrix)
     U <- prep_uniform_data(n, d, U)
-    stopifnot(inherits(vinecop, "vinecop_dist"))
     U <- vinecop_inverse_rosenblatt_cpp(U, vinecop)
     if (!is.null(vinecop$names))
         colnames(U) <- vinecop$names
@@ -99,6 +111,7 @@ print.vinecop_dist <- function(x, ...) {
     if (n_trees < d - 1)
         cat(", ", n_trees, "-truncated", sep = "")
     cat("\n")
+    invisible(x)
 }
 
 #' @importFrom utils capture.output
@@ -108,10 +121,10 @@ summary.vinecop_dist <- function(object, ...) {
     d <- nrow(mat)
     n_trees <- length(object$pair_copulas)
     n_pcs <- length(unlist(object$pair_copulas, recursive = FALSE))
-    mdf <- as.data.frame(matrix(NA, n_pcs, 7))
+    mdf <- as.data.frame(matrix(NA, n_pcs, 9))
     names(mdf) <- c("tree", "edge", 
                     "conditioned", "conditioning", 
-                    "family", "rotation", "parameters")
+                    "family", "rotation", "parameters", "df", "tau")
     k <- 1
     for (t in seq_len(n_trees)) {
         for (e in seq_len(d - t)) {
@@ -120,20 +133,29 @@ summary.vinecop_dist <- function(object, ...) {
             mdf$conditioned[k]  <- list(c(mat[d - e + 1, e], mat[t, e]))
             mdf$conditioning[k] <- list(mat[rev(seq_len(t - 1)), e])
             pc <- object$pair_copulas[[t]][[e]]
-            if (pc$family %in% setdiff(family_set_nonparametric, "indep")) {
-                pc$parameters <- paste0(round(pc$npars, 2), sep = " d.f.")
-            }
             mdf$family[k]     <- pc$family
             mdf$rotation[k]   <- pc$rotation
             mdf$parameters[k] <- list(pc$parameters)
+            mdf$df[k] <- pc$npars
+            mdf$tau[k] <- par_to_ktau(pc)
             k <- k + 1
         }
     }
-    print.vinecop_dist(object)
-    cat(strrep("-", 63), "\n", sep = "")
+    class(mdf) <- c("vinecop_dist_summary", class(mdf))
     mdf
 }
 
+#' @export
+print.vinecop_dist_summary <- function(x, ...) {
+    x_print <- x[1:min(nrow(x), 10), ]
+    x_print[x_print$family == "tll", "parameters"] <- list("[30x30 grid]")
+    cat("# A data.frame:", nrow(x), "x", ncol(x), "\n")
+    print.data.frame(x_print, digits = 2)
+    if (nrow(x) > 10)
+        cat("# ... with", nrow(x) - 10, "more rows\n")
+    invisible(x)
+}
+
 #' Predictions and fitted values for a vine copula model
 #'
 #' Predictions of the density and distribution function
@@ -158,7 +180,7 @@ summary.vinecop_dist <- function(object, ...) {
 #' fit <- vinecop(u, "par")
 #' all.equal(predict(fit, u), fitted(fit))
 predict.vinecop <- function(object, newdata, what = "pdf", n_mc = 10^4, ...) {
-    stopifnot(what %in% c("pdf", "cdf"))
+    assert_that(in_set(what, c("pdf", "cdf")), is.number(n_mc))
     newdata <- if_vec_to_matrix(newdata)
     switch(
         what,
@@ -172,7 +194,7 @@ predict.vinecop <- function(object, newdata, what = "pdf", n_mc = 10^4, ...) {
 fitted.vinecop <- function(object, what = "pdf", n_mc = 10^4, ...) {
     if (is.null(object$data))
         stop("data have not been stored, use keep_data = TRUE when fitting.")
-    stopifnot(what %in% c("pdf", "cdf"))
+    assert_that(in_set(what, c("pdf", "cdf")), is.number(n_mc))
     switch(
         what,
         "pdf" = vinecop_pdf_cpp(object$data, object),
@@ -182,12 +204,7 @@ fitted.vinecop <- function(object, what = "pdf", n_mc = 10^4, ...) {
 
 #' @export
 logLik.vinecop <- function(object, ...) {
-    if (is.null(object$data))
-        stop("data have not been stored, use keep_data = TRUE when fitting.")
-    pc_lst <- unlist(object$pair_copulas, recursive = FALSE)
-    npars <- ifelse(length(pc_lst) == 0, 0, 
-                    sum(sapply(pc_lst, function(x) x[["npars"]])))
-    structure(vinecop_loglik_cpp(object$data, object), "df" = npars)
+    structure(object$loglik, "df" = object$npars)
 }
 
 #' calculates the vine copula Bayesian information criterion (vBIC), which is 
@@ -195,7 +212,7 @@ logLik.vinecop <- function(object, ...) {
 #' \deqn{\mathrm{BIC} = -2\, \mathrm{loglik} +  \nu \ln(n), - 2 * 
 #' \sum_{t=1}^(d - 1) \{q_t log(\psi_0^t) - (d - t - q_t) log(1 - \psi_0^t)\}
 #' }
-#' where \eqn{\mathrm{loglik}} is the log-liklihood and \eqn{\nu} is the
+#' where \eqn{\mathrm{loglik}} is the log-likelihood and \eqn{\nu} is the
 #' (effective) number of parameters of the model, \eqn{t} is the tree level 
 #' \eqn{\psi_0} is the prior probability of having a non-independence copula and 
 #' \eqn{q_t} is the number of non-independence copulas in tree \eqn{t}.
@@ -206,7 +223,7 @@ logLik.vinecop <- function(object, ...) {
 #' @param psi0 baseline prior probability of a non-independence copula.
 #' @export mBICV
 mBICV <- function(object, psi0 = 0.9) {
-    stopifnot(inherits(object, "vinecop_dist"))
+    assert_that(inherits(object, "vinecop_dist"), is.number(psi0))
     if (is.null(object$data))
         stop("data have not been stored, use keep_data = TRUE when fitting.")
     vinecop_mbicv_cpp(object$data, object, psi0)
@@ -238,11 +255,19 @@ print.vinecop <- function(x, ...) {
 
 #' @export
 summary.vinecop <- function(object, ...) {
-    info <- attr(print.vinecop(object), "info")
-    capture.output(s <- summary.vinecop_dist(object))
-    cat(strrep("-", 63), "\n", sep = "")
-    attr(s, "info") <- info
-    s
+    mdf <- summary.vinecop_dist(object)
+    
+    d <- dim(object)
+    n_trees <- length(object$pair_copulas)
+    k <- 1
+    for (t in seq_len(n_trees)) {
+        for (e in seq_len(d - t)) {
+            mdf$loglik[k] <- object$pair_copulas[[t]][[e]]$loglik
+            k <- k + 1
+        }
+    }
+    
+    mdf
 }
 
 
@@ -257,3 +282,67 @@ vinecop_fit_info <- function(vc) {
         BIC    = -2 * ll[1] + log(vc$nobs) * attr(ll, "df")
     )
 }
+
+#' extract a truncated sub-vine based on truncation level supplied by user.
+#' @param object a `vinecop` or a `vine` object.
+#' @param trunc_lvl truncation level for the vine copula.
+#'
+#' @export
+truncate_model <- function(object, trunc_lvl = NA) { 
+    assert_that(inherits(object, "vinecop_dist") || 
+                    inherits(object, "vine_dist"))
+    is_vinecop <- inherits(object, "vinecop_dist")
+    if (is_vinecop) {
+        pcs <- object$pair_copulas
+    } else {
+        pcs <- object$copula$pair_copulas
+    }
+    d <- length(pcs[[1]]) + 1
+    if (!all(is.na(trunc_lvl)))
+        assert_that(is.number(trunc_lvl), trunc_lvl <= d - 1, trunc_lvl > 0)
+    
+    if (!is.na(trunc_lvl)) {
+        n_trees <- length(pcs)
+        trunc_lvl <- min(trunc_lvl, n_trees)
+        
+        # truncate pair_copulas
+        if (is_vinecop) {
+            object$pair_copulas <- pcs[seq_len(trunc_lvl)]
+        } else {
+            object$copula$pair_copulas <- pcs[seq_len(trunc_lvl)]
+        }
+        
+        # adjust npars for truncation
+        pcs <- unlist(pcs[min(trunc_lvl+1,n_trees):n_trees], recursive = FALSE)
+        npars <- ifelse(length(pcs) == 0, 0, 
+                        sum(sapply(pcs, function(x) x[["npars"]])))
+        object$npars <- object$npars - npars
+        
+        # adjust loglik for truncation
+        if (!is.na(object$loglik)) {
+            loglik <- ifelse(length(pcs) == 0, 0, 
+                             sum(sapply(pcs, function(x) x[["loglik"]])))
+            object$loglik <- object$loglik - loglik
+        }
+        
+        # adjust copula object for truncation
+        if (!is_vinecop) {
+            object$copula$npars <- object$copula$npars - npars
+            if (!is.na(object$loglik)) {
+                object$copula$loglik <- object$copula$loglik - loglik
+            }
+        }
+    } else {
+        if (is_vinecop) {
+            object$pair_copulas <- pcs
+        } else {
+            object$copula$pair_copulas <- pcs
+        }
+    }
+    return(object)
+}
+
+#' @export
+dim.vinecop_dist <- function(x) {
+    ncol(x$matrix)
+}
\ No newline at end of file
