@@ -10,7 +10,7 @@ test_that("returns proper 'bicop' object", {
     expect_s3_class(fit, "bicop_dist")
     expect_identical(
         names(fit), 
-        c("family", "rotation", "parameters", "npars", "data", "controls", "nobs")
+        c("family", "rotation", "parameters", "npars", "loglik", "data", "controls", "nobs")
     )
     
     fit <- bicop(u, "tll", keep_data = FALSE)
@@ -18,13 +18,13 @@ test_that("returns proper 'bicop' object", {
     expect_s3_class(fit, "bicop_dist")
     expect_identical(
         names(fit), 
-        c("family", "rotation", "parameters", "npars", "controls", "nobs")
+        c("family", "rotation", "parameters", "npars", "loglik", "controls", "nobs")
     )
     
     colnames(u) <- paste(1:2)
     expect_identical(
         names(bicop(u, "indep")), 
-        c("family", "rotation", "parameters", "npars", "names", "data", "controls", "nobs")
+        c("family", "rotation", "parameters", "npars", "loglik", "names", "data", "controls", "nobs")
     )
 })
 
@@ -41,6 +41,7 @@ test_that("S3 generics work", {
     expect_equal(predict(fit, u, what = "hfunc2"), fitted(fit, what = "hfunc2"))
     expect_equal(predict(fit, u, what = "hinv1"), fitted(fit, what = "hinv1"))
     expect_equal(predict(fit, u, what = "hinv2"), fitted(fit, what = "hinv2"))
+    u <- as.data.frame(u)
     expect_equivalent(logLik(fit), sum(log(predict(fit, u, what = "pdf"))))
     expect_output(print(fit))
     expect_output(summary(fit))
