@@ -1,26 +1,26 @@
-context("Fitting vine copula models")
+context("Fitting 'vinecop' models")
 
 set.seed(5)
 u <- sapply(1:5, function(i) runif(30))
 fit <- vinecop(u, "nonpar")
 fit_no_data <- vinecop(u, "nonpar", keep_data = FALSE)
 
-test_that("returns proper 'bicop' object", {
+test_that("returns proper 'vinecop' object", {
     expect_s3_class(fit, "vinecop")
     expect_s3_class(fit, "vinecop_dist")
     expect_identical(
         names(fit),  
-        c("pair_copulas", "matrix", "npars", "threshold", "data", "controls", "nobs")
+        c("pair_copulas", "matrix", "npars", "loglik", "threshold", "data", "controls", "nobs")
     )
     expect_identical(
         names(fit_no_data), 
-        c("pair_copulas", "matrix", "npars", "threshold", "controls", "nobs")
+        c("pair_copulas", "matrix", "npars", "loglik", "threshold", "controls", "nobs")
     )
     
     colnames(u) <- paste(seq_len(ncol(u)))
     expect_identical(
         names(vinecop(u, "indep")), 
-        c("pair_copulas", "matrix", "npars", "threshold", "names", "data", "controls", "nobs")
+        c("pair_copulas", "matrix", "npars", "loglik", "threshold", "names", "data", "controls", "nobs")
     )
 })
 
@@ -42,12 +42,10 @@ test_that("S3 generics work", {
     )
     expect_error(predict(fit, u, what = "hfunc1"))
     expect_length(attr(logLik(fit), "df"), 1)
-    expect_error(logLik(fit_no_data))
 })
 
 test_that("print/summary generics work", {
     expect_output(print(fit))
-    expect_output(s <- summary(fit))
+    expect_s3_class(s <- summary(fit), "vinecop_dist_summary")
     expect_is(s, "data.frame")
-    expect_length(attr(s, "info"), 5)
 })
\ No newline at end of file
